NXSConfigServer Tango Class Command DependentComponents

Command DependentComponents :

Returns a list of dependent component names for a given components

DependentComponents Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | component names
Output Argument | Tango::DEVVAR_STRINGARRAY | list of component names
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..